@@ -2,7 +2,7 @@
 
 """Module for testing instances in Azure."""
 
-# Copyright (c) 2019 SUSE LLC. All rights reserved.
+# Copyright (c) 2020 SUSE LLC. All rights reserved.
 #
 # This file is part of img_proof. img_proof provides an api and command line
 # utilities for testing images in the Public Cloud.
@@ -22,7 +22,7 @@
 
 import os
 
-from azure.common.client_factory import get_client_from_auth_file
+from azure.identity import ClientSecretCredential
 from azure.mgmt.resource import ResourceManagementClient
 from azure.mgmt.network import NetworkManagementClient
 from azure.mgmt.compute import ComputeManagementClient
@@ -31,70 +31,23 @@ from img_proof import ipa_utils
 from img_proof.ipa_constants import AZURE_DEFAULT_TYPE, AZURE_DEFAULT_USER
 from img_proof.ipa_exceptions import AzureCloudException
 from img_proof.ipa_cloud import IpaCloud
+from img_proof.azure_creds_wrapper import CredentialWrapper
 
 
 class AzureCloud(IpaCloud):
     """Class for testing instances in Azure."""
+    cloud = 'azure'
 
-    def __init__(
-        self,
-        accelerated_networking=False,
-        cleanup=None,
-        config=None,
-        description=None,
-        distro_name=None,
-        early_exit=None,
-        history_log=None,
-        image_id=None,
-        inject=None,
-        instance_type=None,
-        log_level=None,
-        no_default_test_dirs=False,
-        cloud_config=None,
-        region=None,
-        results_dir=None,
-        running_instance_id=None,
-        service_account_file=None,
-        ssh_private_key_file=None,
-        ssh_user=None,
-        subnet_id=None,
-        test_dirs=None,
-        test_files=None,
-        timeout=None,
-        vnet_name=None,
-        vnet_resource_group=None,
-        collect_vm_info=None
-    ):
-        """Initialize Azure Cloud class."""
-        super(AzureCloud, self).__init__(
-            'azure',
-            cleanup,
-            config,
-            description,
-            distro_name,
-            early_exit,
-            history_log,
-            image_id,
-            inject,
-            instance_type,
-            log_level,
-            no_default_test_dirs,
-            cloud_config,
-            region,
-            results_dir,
-            running_instance_id,
-            test_dirs,
-            test_files,
-            timeout,
-            collect_vm_info,
-            ssh_private_key_file,
-            ssh_user,
-            subnet_id
+    def post_init(self):
+        """Initialize Azure cloud framework class."""
+
+        self.vnet_name = (
+                self.custom_args.get('vnet_name')
+                or self.ipa_config['vnet_name']
         )
-
-        self.vnet_name = vnet_name or self.ipa_config['vnet_name']
         self.vnet_resource_group = (
-                vnet_resource_group or self.ipa_config['vnet_resource_group']
+            self.custom_args.get('vnet_resource_group')
+            or self.ipa_config['vnet_resource_group']
         )
 
         subnet_args = [
@@ -107,7 +60,8 @@ class AzureCloud(IpaCloud):
             )
 
         self.service_account_file = (
-            service_account_file or self.ipa_config['service_account_file']
+            self.custom_args.get('service_account_file')
+            or self.ipa_config['service_account_file']
         )
         if not self.service_account_file:
             raise AzureCloudException(
@@ -124,14 +78,17 @@ class AzureCloud(IpaCloud):
             )
 
         self.accelerated_networking = (
-            accelerated_networking or
-            self.ipa_config['accelerated_networking']
+            self.custom_args.get('accelerated_networking')
+            or self.ipa_config['accelerated_networking']
         )
         self.ssh_user = self.ssh_user or AZURE_DEFAULT_USER
         self.ssh_public_key = self._get_ssh_public_key()
 
         self.compute = self._get_management_client(ComputeManagementClient)
-        self.network = self._get_management_client(NetworkManagementClient)
+        self.network = self._get_management_client(
+            NetworkManagementClient,
+            wrap_creds=False
+        )
         self.resource = self._get_management_client(ResourceManagementClient)
 
         if self.running_instance_id:
@@ -164,7 +121,7 @@ class AzureCloud(IpaCloud):
             nic_config['enable_accelerated_networking'] = True
 
         try:
-            nic_setup = self.network.network_interfaces.create_or_update(
+            nic_setup = self.network.network_interfaces.begin_create_or_update(
                 resource_group_name, nic_name, nic_config
             )
         except Exception as error:
@@ -187,7 +144,7 @@ class AzureCloud(IpaCloud):
 
         try:
             public_ip_setup = \
-                self.network.public_ip_addresses.create_or_update(
+                self.network.public_ip_addresses.begin_create_or_update(
                     resource_group_name, public_ip_name, public_ip_config
                 )
         except Exception as error:
@@ -252,7 +209,7 @@ class AzureCloud(IpaCloud):
         subnet_config = {'address_prefix': '10.0.0.0/29'}
 
         try:
-            subnet_setup = self.network.subnets.create_or_update(
+            subnet_setup = self.network.subnets.begin_create_or_update(
                 resource_group_name, vnet_name, subnet_id, subnet_config
             )
         except Exception as error:
@@ -274,7 +231,7 @@ class AzureCloud(IpaCloud):
         }
 
         try:
-            vnet_setup = self.network.virtual_networks.create_or_update(
+            vnet_setup = self.network.virtual_networks.begin_create_or_update(
                 resource_group_name, vnet_name, vnet_config
             )
         except Exception as error:
@@ -282,14 +239,14 @@ class AzureCloud(IpaCloud):
                 'Unable to create vnet: {0}.'.format(error)
             )
 
-        vnet_setup.wait()
+        vnet_setup.result()
 
     def _create_vm(self, vm_config):
         """
         Attempt to create or update VM instance based on vm_parameters config.
         """
         try:
-            vm_setup = self.compute.virtual_machines.create_or_update(
+            vm_setup = self.compute.virtual_machines.begin_create_or_update(
                 self.running_instance_id, self.running_instance_id,
                 vm_config
             )
@@ -300,7 +257,7 @@ class AzureCloud(IpaCloud):
                 )
             )
 
-        vm_setup.wait()
+        vm_setup.result()
 
     def _create_vm_config(self, interface):
         """
@@ -377,13 +334,36 @@ class AzureCloud(IpaCloud):
             if status.code.startswith('PowerState'):
                 return status.display_status
 
-    def _get_management_client(self, client_class):
+    def _get_client_from_json(self, client, credentials, wrap_creds=True):
+        credential = self._get_secret_credential(credentials)
+
+        if wrap_creds:
+            credential = CredentialWrapper(credential)
+
+        return client(
+            credential,
+            credentials['subscriptionId']
+        )
+
+    @staticmethod
+    def _get_secret_credential(credentials):
+        return ClientSecretCredential(
+            tenant_id=credentials['tenantId'],
+            client_id=credentials['clientId'],
+            client_secret=credentials['clientSecret']
+        )
+
+    def _get_management_client(self, client_class, wrap_creds=True):
         """
         Return instance of resource management client.
         """
+        credentials = ipa_utils.load_json(self.service_account_file)
+
         try:
-            client = get_client_from_auth_file(
-                client_class, auth_path=self.service_account_file
+            client = self._get_client_from_json(
+                client_class,
+                credentials,
+                wrap_creds=wrap_creds
             )
         except ValueError as error:
             raise AzureCloudException(
@@ -405,7 +385,7 @@ class AzureCloud(IpaCloud):
         """
         Generate SSH public key from private key.
         """
-        key = ipa_utils.generate_public_ssh_key(self.ssh_private_key_file)
+        key = ipa_utils.get_public_ssh_key(self.ssh_private_key_file)
         return key.decode()
 
     def _is_instance_running(self):
@@ -418,9 +398,7 @@ class AzureCloud(IpaCloud):
         """
         Create new test instance in a resource group with the same name.
         """
-        self.running_instance_id = ipa_utils.generate_instance_name(
-            'azure-img-proof-test'
-        )
+        self.running_instance_id = self._generate_instance_name()
         self.logger.debug('ID of instance: %s' % self.running_instance_id)
         self._set_default_resource_names()
 
@@ -545,7 +523,7 @@ class AzureCloud(IpaCloud):
         Start the instance.
         """
         try:
-            vm_start = self.compute.virtual_machines.start(
+            vm_start = self.compute.virtual_machines.begin_start(
                 self.running_instance_id, self.running_instance_id
             )
         except Exception as error:
@@ -553,14 +531,14 @@ class AzureCloud(IpaCloud):
                 'Unable to start instance: {0}.'.format(error)
             )
 
-        vm_start.wait()
+        vm_start.result()
 
     def _stop_instance(self):
         """
         Stop the instance.
         """
         try:
-            vm_stop = self.compute.virtual_machines.power_off(
+            vm_stop = self.compute.virtual_machines.begin_power_off(
                 self.running_instance_id, self.running_instance_id
             )
         except Exception as error:
@@ -568,14 +546,16 @@ class AzureCloud(IpaCloud):
                 'Unable to stop instance: {0}.'.format(error)
             )
 
-        vm_stop.wait()
+        vm_stop.result()
 
     def _terminate_instance(self):
         """
         Terminate the resource group and instance.
         """
         try:
-            self.resource.resource_groups.delete(self.running_instance_id)
+            self.resource.resource_groups.delete(
+                self.running_instance_id
+            )
         except Exception as error:
             raise AzureCloudException(
                 'Unable to terminate resource group: {0}.'.format(error)
