@@ -30,6 +30,7 @@ import pytest
 
 from collections import ChainMap, defaultdict
 from datetime import datetime
+from distutils.util import strtobool
 
 from img_proof import ipa_utils
 from img_proof.ipa_constants import (
@@ -40,16 +41,16 @@ from img_proof.ipa_constants import (
     NOT_IMPLEMENTED,
     TEST_PATHS
 )
+from img_proof.ipa_rhel import RHEL
+from img_proof.ipa_fedora import Fedora
 from img_proof.ipa_opensuse_leap import openSUSE_Leap
 from img_proof.ipa_sles import SLES
 from img_proof.ipa_exceptions import (
     IpaException,
     IpaCloudException,
-    IpaSSHException,
-    IpaRetryableError,
-    GCECloudRetryableError
+    IpaSSHException
 )
-from img_proof.results_plugin import Report
+from pytest_jsonreport.plugin import JSONReport
 
 default_values = {
     'collect_vm_info': False,
@@ -58,7 +59,9 @@ default_values = {
     'log_level': logging.INFO,
     'results_dir': IPA_RESULTS_PATH,
     'test_files': set(),
-    'timeout': 600
+    'timeout': 600,
+    'no_default_test_dirs': False,
+    'retry_count': 3
 }
 
 
@@ -70,10 +73,10 @@ class IpaCloud(object):
     modules extend the base class and implement cloud
     specific methods for launching and managing instances.
     """
+    cloud = 'base'
 
     def __init__(
         self,
-        cloud,
         cleanup=None,
         config=None,
         description=None,
@@ -84,7 +87,7 @@ class IpaCloud(object):
         inject=None,
         instance_type=None,
         log_level=None,
-        no_default_test_dirs=False,
+        no_default_test_dirs=None,
         cloud_config=None,
         region=None,
         results_dir=None,
@@ -95,7 +98,13 @@ class IpaCloud(object):
         collect_vm_info=None,
         ssh_private_key_file=None,
         ssh_user=None,
-        subnet_id=None
+        subnet_id=None,
+        enable_secure_boot=None,
+        enable_uefi=None,
+        log_callback=None,
+        prefix_name=None,
+        retry_count=None,
+        custom_args=None
     ):
         """Initialize base cloud framework class."""
         super(IpaCloud, self).__init__()
@@ -104,21 +113,19 @@ class IpaCloud(object):
 
         ipa_utils.clear_cache()
 
-        self.cloud = cloud
+        self.custom_args = custom_args if custom_args else {}
         self.host_key_fingerprint = None
         self.instance_ip = None
 
         self.config = config or default_values['config']
         log_level = log_level or default_values['log_level']
 
-        self.logger = logging.getLogger('img_proof')
-        self.logger.setLevel(log_level)
-
-        console_handler = logging.StreamHandler()
-        console_handler.setLevel(log_level)
-        console_handler.setFormatter(logging.Formatter('%(message)s'))
-
-        self.logger.addHandler(console_handler)
+        if log_callback:
+            self.logger = log_callback
+        else:
+            self.logger = logging.getLogger('img_proof')
+            self.logger.setLevel(log_level)
+            self.logger.propagate = False
 
         try:
             self.ipa_config = ipa_utils.get_config_values(
@@ -157,6 +164,16 @@ class IpaCloud(object):
         self.ssh_private_key_file = self.ipa_config['ssh_private_key_file']
         self.ssh_user = self.ipa_config['ssh_user']
         self.subnet_id = self.ipa_config['subnet_id']
+        self.enable_secure_boot = self.ipa_config['enable_secure_boot']
+        self.enable_uefi = self.ipa_config['enable_uefi']
+        self.no_default_test_dirs = bool(
+            strtobool(str(self.ipa_config['no_default_test_dirs']))
+        )
+        self.prefix_name = self.ipa_config['prefix_name']
+        self.retry_count = int(self.ipa_config['retry_count'])
+
+        if self.enable_secure_boot and not self.enable_uefi:
+            self.enable_uefi = True
 
         if self.cloud_config:
             self.cloud_config = os.path.expanduser(self.cloud_config)
@@ -187,7 +204,11 @@ class IpaCloud(object):
             )
         }
 
-        self._parse_test_files(test_dirs, no_default_test_dirs)
+        self._parse_test_files(test_dirs, self.no_default_test_dirs)
+        self.post_init()
+
+    def post_init(self):
+        pass
 
     def _get_instance(self):
         raise NotImplementedError(NOT_IMPLEMENTED)
@@ -218,9 +239,9 @@ class IpaCloud(object):
         to the instance. The public key is generated from the
         private key file.
         """
-        key = ipa_utils.generate_public_ssh_key(
+        key = ipa_utils.get_public_ssh_key(
             self.ssh_private_key_file
-        ).decode()
+        ).decode().strip()
 
         script = BASH_SSH_SCRIPT.format(user=self.ssh_user, key=key)
         return script
@@ -233,26 +254,18 @@ class IpaCloud(object):
 
     def _log_info(self):
         """Output test run information to top of log file."""
-        if self.cloud == 'ssh':
-            self.results['info'] = {
-                'platform': self.cloud,
-                'distro': self.distro_name,
-                'image': self.instance_ip,
-                'timestamp': self.time_stamp,
-                'log_file': self.log_file,
-                'results_file': self.results_file
-            }
-        else:
-            self.results['info'] = {
-                'platform': self.cloud,
-                'region': self.region,
-                'distro': self.distro_name,
-                'image': self.image_id,
-                'instance': self.running_instance_id,
-                'timestamp': self.time_stamp,
-                'log_file': self.log_file,
-                'results_file': self.results_file
-            }
+        self.results['info'] = {
+            'platform': self.cloud,
+            'distro': self.distro_name,
+            'image': self.instance_ip,
+            'timestamp': self.time_stamp,
+            'log_file': self.log_file,
+            'results_file': self.results_file
+        }
+
+        if self.cloud != 'ssh':
+            self.results['info']['region'] = self.region
+            self.results['info']['instance'] = self.running_instance_id
 
         self._write_to_log(
             '\n'.join(
@@ -319,41 +332,59 @@ class IpaCloud(object):
                 {
                     'outcome': status,
                     'test_index': 0,
-                    'name': test_name
+                    'nodeid': test_name
                 }
             ],
             'summary': {
                 'duration': duration,
                 status: 1,
-                'num_tests': 1
+                'total': 1
             }
         }
         self._merge_results(result)
 
-    def _run_tests(self, tests, ssh_config):
-        """Run the test suite on the image."""
+    def _run_test(self, test, ssh_config):
+        """Run the test on the image."""
+        self.logger.info('Running test {name}'.format(name=test))
+
         options = []
         if self.early_exit:
             options.append('-x')
 
-        args = '-v {} --ssh-config={} --hosts={} {}'.format(
-                ' '.join(options),
-                ssh_config,
-                self.instance_ip,
-                ' '.join(tests)
-            )
+        args = '-v -s {} --json-report-file=none ' \
+               '--ssh-config={} --hosts={} {}'.format(
+                   ' '.join(options),
+                   ssh_config,
+                   self.instance_ip,
+                   test
+               )
 
         # Print output captured to log file for test run
-        print(
+        self.logger.debug(
             '\nTest directories:\n{}\n'.format(
                 '\n'.join(self.test_dirs)
             )
         )
-        print('Arguments:\n{}\n'.format(args))
+        self.logger.debug('Arguments:\n{}\n'.format(args))
 
         cmds = shlex.split(args)
-        plugin = Report()
-        result = pytest.main(cmds, plugins=[plugin])
+        num_retries = 0
+
+        while num_retries < self.retry_count:
+            plugin = JSONReport()
+
+            try:
+                with open(self.log_file, 'a') as log_file:
+                    with ipa_utils.redirect_output(log_file):
+                        result = pytest.main(cmds, plugins=[plugin])
+            except Exception as error:
+                result = 3  # See below for pytest error codes
+                self.logger.exception(str(error))
+
+            if result != 0:
+                num_retries += 1
+            else:
+                break
 
         # If pytest has an error there will be no report but
         # we still want to process the error as a failure.
@@ -372,10 +403,14 @@ class IpaCloud(object):
 
     def _set_distro(self):
         """Determine distro for image and create instance of class."""
-        if self.distro_name == 'sles':
-            self.distro = SLES()
+        if self.distro_name == 'fedora':
+            self.distro = Fedora()
         elif self.distro_name == 'opensuse_leap':
             self.distro = openSUSE_Leap()
+        elif self.distro_name == 'rhel':
+            self.distro = RHEL()
+        elif self.distro_name == 'sles':
+            self.distro = SLES()
         else:
             raise IpaCloudException(
                 'Distribution: %s, not supported.' % self.distro_name
@@ -422,14 +457,6 @@ class IpaCloud(object):
         )
         self.logger.debug('Created results file %s' % self.results_file)
 
-        # Add log file handler
-        file_handler = logging.FileHandler(self.log_file)
-        file_handler.setLevel(logging.DEBUG)
-        file_handler.setFormatter(
-            logging.Formatter('\n%(asctime)s: %(message)s\n')
-        )
-        self.logger.addHandler(file_handler)
-
     def _start_instance(self):
         """Start the instance."""
         raise NotImplementedError(NOT_IMPLEMENTED)
@@ -632,6 +659,19 @@ class IpaCloud(object):
             )
             self._terminate_instance()
 
+    def _generate_instance_name(self):
+        """
+        Generate a new instance name with a random string appended.
+
+        If a prefix is supplied add to the beginning of instance name.
+        """
+        instance_name = ipa_utils.generate_instance_name('img-proof')
+
+        if self.prefix_name:
+            instance_name = '-'.join([self.prefix_name, instance_name])
+
+        return instance_name
+
     def get_console_log(self):
         """
         Return console log output if it is available.
@@ -668,19 +708,11 @@ class IpaCloud(object):
             self.logger.info('Launching new instance')
             try:
                 self._launch_instance()
-            except GCECloudRetryableError as error:
-                with ipa_utils.ignored(Exception):
-                    self._cleanup_instance(1)
-
-                msg = 'Unable to connect to instance: %s' % error
-                self.logger.error(msg)
-                raise IpaRetryableError(msg)
             except Exception as error:
                 with ipa_utils.ignored(Exception):
                     self._cleanup_instance(1)
 
-                msg = 'Unable to connect to instance: %s' % error
-                self.logger.error(msg)
+                self.logger.error(error)
                 raise
 
         if not self.instance_ip:
@@ -828,14 +860,10 @@ class IpaCloud(object):
                         )
                         status = status or result
 
-                elif isinstance(item, set):
-                    self.logger.info('Running tests %s' % ' '.join(item))
-                    with open(self.log_file, 'a') as log_file:
-                        with ipa_utils.redirect_output(log_file):
-                            # Run tests
-                            result = self._run_tests(item, ssh_config)
-                            status = status or result
-
+                elif isinstance(item, str):
+                    # Run tests
+                    result = self._run_test(item, ssh_config)
+                    status = status or result
                 else:
                     self.logger.error(
                         'Invalid test item in list: %s' % item
