@@ -2,7 +2,7 @@
 
 """Cloud module for testing Oracle OCI images."""
 
-# Copyright (c) 2019 SUSE LLC. All rights reserved.
+# Copyright (c) 2020 SUSE LLC. All rights reserved.
 #
 # This file is part of ipa. Ipa provides an api and command line
 # utilities for testing images in the Public Cloud.
@@ -33,67 +33,14 @@ from img_proof.ipa_cloud import IpaCloud
 
 class OCICloud(IpaCloud):
     """Cloud framework class for testing Oracle OCI images."""
+    cloud = 'oci'
 
-    def __init__(
-        self,
-        cleanup=None,
-        config=None,
-        description=None,
-        distro_name=None,
-        early_exit=None,
-        history_log=None,
-        image_id=None,
-        inject=None,
-        instance_type=None,
-        log_level=None,
-        no_default_test_dirs=False,
-        cloud_config=None,
-        region=None,
-        results_dir=None,
-        running_instance_id=None,
-        ssh_private_key_file=None,
-        ssh_user=None,
-        subnet_id=None,
-        test_dirs=None,
-        test_files=None,
-        timeout=None,
-        collect_vm_info=None,
-        compartment_id=None,
-        availability_domain=None,
-        signing_key_fingerprint=None,
-        signing_key_file=None,
-        tenancy=None,
-        oci_user_id=None
-    ):
+    def post_init(self):
         """Initialize OCI cloud framework class."""
-        super(OCICloud, self).__init__(
-            'oci',
-            cleanup,
-            config,
-            description,
-            distro_name,
-            early_exit,
-            history_log,
-            image_id,
-            inject,
-            instance_type,
-            log_level,
-            no_default_test_dirs,
-            cloud_config,
-            region,
-            results_dir,
-            running_instance_id,
-            test_dirs,
-            test_files,
-            timeout,
-            collect_vm_info,
-            ssh_private_key_file,
-            ssh_user,
-            subnet_id
-        )
 
         self.availability_domain = (
-            availability_domain or self.ipa_config['availability_domain']
+            self.custom_args.get('availability_domain')
+            or self.ipa_config['availability_domain']
         )
 
         if not self.availability_domain:
@@ -102,7 +49,8 @@ class OCICloud(IpaCloud):
             )
 
         self.compartment_id = (
-            compartment_id or self.ipa_config['compartment_id']
+            self.custom_args.get('compartment_id')
+            or self.ipa_config['compartment_id']
         )
 
         if not self.compartment_id:
@@ -116,15 +64,20 @@ class OCICloud(IpaCloud):
             )
 
         self.ssh_user = self.ssh_user or OCI_DEFAULT_USER
-        self.subnet_id = subnet_id or self.ipa_config['subnet_id']
-        self.oci_user_id = oci_user_id or self.ipa_config['oci_user_id']
-        self.tenancy = tenancy or self.ipa_config['tenancy']
+        self.oci_user_id = (
+            self.custom_args.get('oci_user_id')
+            or self.ipa_config['oci_user_id']
+        )
+        self.tenancy = (
+            self.custom_args.get('tenancy') or self.ipa_config['tenancy']
+        )
         self.signing_key_fingerprint = (
-            signing_key_fingerprint
+            self.custom_args.get('signing_key_fingerprint')
             or self.ipa_config['signing_key_fingerprint']
         )
         self.signing_key_file = (
-            signing_key_file or self.ipa_config['signing_key_file']
+            self.custom_args.get('signing_key_file')
+            or self.ipa_config['signing_key_file']
         )
 
         config = self._get_config()
@@ -403,21 +356,38 @@ class OCICloud(IpaCloud):
 
     def _get_ssh_public_key(self):
         """Generate SSH public key from private key."""
-        key = ipa_utils.generate_public_ssh_key(self.ssh_private_key_file)
+        key = ipa_utils.get_public_ssh_key(self.ssh_private_key_file)
         return key.decode()
 
     def get_console_log(self):
         """
         Return console log output if it is available.
-
-        Todo: The get_console_history_content method does not appear to work
-              during initial implementation. Consider this in the future.
         """
-        return ''
+        states = [
+            oci.core.models.ConsoleHistory.LIFECYCLE_STATE_SUCCEEDED
+        ]
+
+        try:
+            history_details = oci.core.models.CaptureConsoleHistoryDetails(
+                instance_id=self.running_instance_id
+            )
+            result = self.compute_composite_client.\
+                capture_console_history_and_wait_for_state(
+                    history_details,
+                    wait_for_states=states
+                ).data
+            output = self.compute_client.get_console_history_content(
+                result.id
+            ).data
+            history = output.decode()
+        except Exception:
+            history = ''
+
+        return history
 
     def _launch_instance(self):
         """Launch an instance of the given image."""
-        self.display_name = ipa_utils.generate_instance_name('oci-ipa-test')
+        self.display_name = self._generate_instance_name()
 
         try:
             if not self.subnet_id:
