@@ -2,7 +2,7 @@
 
 """img-proof CLI endpoints using click library."""
 
-# Copyright (c) 2019 SUSE LLC. All rights reserved.
+# Copyright (c) 2020 SUSE LLC. All rights reserved.
 #
 # This file is part of img-proof. img-proof provides an api and command line
 # utilities for testing images in the Public Cloud.
@@ -91,6 +91,14 @@ def main(context, no_color):
     '--access-key-id',
     help='EC2 access key ID for login credentials.'
 )
+@click.option(
+    '--access-key',
+    help='Aliyun access key for login credentials.'
+)
+@click.option(
+    '--access-secret',
+    help='Aliyun access secret for login credentials.'
+)
 @click.option(
     '-a',
     '--account',
@@ -136,6 +144,12 @@ def main(context, no_color):
     '--image-id',
     help='The ID of the image used for instance.'
 )
+@click.option(
+    '--image-project',
+    help='The image project where the image exists. This is required if '
+         'testing an image in a project different than the service account '
+         'project.'
+)
 @click.option(
     '--inject',
     help='Path to an injection yaml config file.',
@@ -172,7 +186,7 @@ def main(context, no_color):
 @click.option(
     '--no-default-test-dirs',
     is_flag=True,
-    default=False,
+    default=None,
     help='Do not include default test directories in search for tests.'
 )
 @click.option(
@@ -273,11 +287,60 @@ def main(context, no_color):
     '--oci-user-id',
     help='The ID for the OCI user.'
 )
+@click.option(
+    '--enable-secure-boot',
+    is_flag=True,
+    help='Enable secure boot for the instance. Secure boot requires '
+         'UEFI boot firmware.'
+)
+@click.option(
+    '--enable-uefi',
+    is_flag=True,
+    help='Enable boot firmware for the instance. By default secure boot '
+         'is disabled.'
+)
+@click.option(
+    '--prefix-name',
+    help='Optional prefix to append to the test instance name or ID '
+         'depending on the cloud framework. EC2 and OCI use autogenerated '
+         'IDs thus the prefix is added to the display name.'
+)
+@click.option(
+    '--retry-count',
+    help='The number of times a test should be re-run if it fails. '
+         'The default is 3 times before the test is marked as failed. '
+         'This is helpful due to the possibility for flaky SSH sessions '
+         'and/or network connections.',
+    type=click.IntRange(min=0)
+)
+@click.option(
+    '--v-switch-id',
+    help='ID for the Aliyun VSwitch to attach to the instance.'
+)
+@click.option(
+    '--sev-capable',
+    is_flag=True,
+    help='Enable confidential computing in GCE via Secure Encrypted '
+         'Virtualization (SEV) feature.'
+)
+@click.option(
+    '--additional-info',
+    help='Additional info to add during instance start or creation '
+         'when using EC2 provider.'
+)
+@click.option(
+    '--use-gvnic',
+    is_flag=True,
+    help='Use a Google Virtual NIC (gVNIC) network interface. '
+         '(GCE only)'
+)
 @click.argument('tests', nargs=-1)
 @click.pass_context
 def test(context,
          accelerated_networking,
          access_key_id,
+         access_key,
+         access_secret,
          account,
          cleanup,
          config,
@@ -286,6 +349,7 @@ def test(context,
          early_exit,
          history_log,
          image_id,
+         image_project,
          inject,
          instance_type,
          ip_address,
@@ -314,14 +378,26 @@ def test(context,
          signing_key_file,
          tenancy,
          oci_user_id,
+         enable_secure_boot,
+         enable_uefi,
+         prefix_name,
+         retry_count,
+         v_switch_id,
+         sev_capable,
+         additional_info,
+         use_gvnic,
          tests):
     """Test image in the given framework using the supplied test files."""
     no_color = context.obj['no_color']
+    logger = ipa_utils.get_logger(log_level)
+
     try:
         status, results = test_image(
             cloud,
             accelerated_networking,
             access_key_id,
+            access_key,
+            access_secret,
             account,
             cleanup,
             config,
@@ -330,6 +406,7 @@ def test(context,
             early_exit,
             history_log,
             image_id,
+            image_project,
             inject,
             instance_type,
             ip_address,
@@ -358,6 +435,15 @@ def test(context,
             signing_key_file,
             tenancy,
             oci_user_id,
+            enable_secure_boot,
+            enable_uefi,
+            logger,
+            prefix_name,
+            retry_count,
+            v_switch_id,
+            sev_capable,
+            additional_info,
+            use_gvnic
         )
         echo_results(results, no_color)
         sys.exit(status)
