@@ -41,15 +41,19 @@ class TestOCIProvider(object):
             'no_default_test_dirs': True,
             'cloud_config': 'tests/oci/config',
             'test_files': ['test_image'],
-            'oci_user_id':
-                'ocid1.user.oc1..'
-                'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa',
-            'signing_key_fingerprint':
-                '00:00:00:00:00:00:00:00:00:00:00:00:00:00:00:00',
-            'signing_key_file': 'tests/oci/api_key.pem',
-            'tenancy':
-                'ocid1.tenancy.oc1..'
-                'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'
+            'custom_args': {
+                'oci_user_id':
+                    'ocid1.user.oc1..'
+                    'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'
+                    'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaa',
+                'signing_key_fingerprint':
+                    '00:00:00:00:00:00:00:00:00:00:00:00:00:00:00:00',
+                'signing_key_file': 'tests/oci/api_key.pem',
+                'tenancy':
+                    'ocid1.tenancy.oc1..'
+                    'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'
+                    'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'
+            }
         }
 
     def test_oci_exception_required_args(self):
@@ -58,13 +62,13 @@ class TestOCIProvider(object):
         with pytest.raises(OCICloudException):
             OCICloud(**self.kwargs)
 
-        self.kwargs['availability_domain'] = 'Omic:PHX-AD-1'
+        self.kwargs['custom_args']['availability_domain'] = 'Omic:PHX-AD-1'
 
         # Test missing compartment id
         with pytest.raises(OCICloudException):
             OCICloud(**self.kwargs)
 
-        self.kwargs['compartment_id'] = (
+        self.kwargs['custom_args']['compartment_id'] = (
             'ocid1.compartment.oc1..'
             'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'
         )
@@ -83,8 +87,8 @@ class TestOCIProvider(object):
         mock_oci.core.VirtualNetworkClient.return_value = client
         mock_oci.core.VirtualNetworkClientCompsiteOperations.return_value = client  # noqa
 
-        self.kwargs['availability_domain'] = 'Omic:PHX-AD-1'
-        self.kwargs['compartment_id'] = (
+        self.kwargs['custom_args']['availability_domain'] = 'Omic:PHX-AD-1'
+        self.kwargs['custom_args']['compartment_id'] = (
             'ocid1.compartment.oc1..'
             'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'
         )
@@ -437,12 +441,12 @@ class TestOCIProvider(object):
 
         cloud._get_vnic_attachments(compartment_id, instance_id)
 
-    @patch('img_proof.ipa_utils.generate_public_ssh_key')
+    @patch('img_proof.ipa_utils.get_public_ssh_key')
     @patch.object(OCICloud, '__init__')
-    def test_get_ssh_public_key(self, mock_init, mock_generate_public_ssh_key):
+    def test_get_ssh_public_key(self, mock_init, mock_get_public_ssh_key):
         """Test oci get ssh public key method."""
         mock_init.return_value = None
-        mock_generate_public_ssh_key.return_value = b'key123'
+        mock_get_public_ssh_key.return_value = b'key123'
 
         cloud = OCICloud(**self.kwargs)
         cloud.ssh_private_key_file = 'tests/oci/api_key.pem'
@@ -454,8 +458,18 @@ class TestOCIProvider(object):
     def test_get_console_log(self, mock_init):
         """Test oci get console log method."""
         mock_init.return_value = None
+        response = MagicMock()
+        response.data = b'Test output'
+        client = MagicMock()
+        client.get_console_history_content.return_value = response
+
         cloud = OCICloud(**self.kwargs)
-        cloud.get_console_log()
+        cloud.compute_client = client
+        cloud.compute_composite_client = client
+        cloud.running_instance_id = 'instance-123'
+
+        log = cloud.get_console_log()
+        assert log == 'Test output'
 
     @patch.object(OCICloud, '_wait_on_instance')
     @patch.object(OCICloud, '_terminate_instance')
@@ -505,6 +519,7 @@ class TestOCIProvider(object):
         cloud.instance_type = None
         cloud.image_id = 'image123'
         cloud.logger = logger
+        cloud.prefix_name = None
 
         cloud._launch_instance()
 
